==> qt-creator-opensource-src-4.0.0.zip: qt-creator-opensource-src-4.0.0/src/plugins/qmlprofiler/qmlprofilerbindingloopsrenderpass.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef QMLPROFILERBINDINGLOOPSRENDERPASS_H
#define QMLPROFILERBINDINGLOOPSRENDERPASS_H

#include "timeline/timelineabstractrenderer.h"
#include "timeline/timelinerenderpass.h"
#include "timeline/timelinerenderstate.h"
#include "qmlprofilerrangemodel.h"
#include <QSGMaterial>

namespace QmlProfiler {
namespace Internal {

class QmlProfilerBindingLoopsRenderPass : public Timeline::TimelineRenderPass
{
public:
    static const QmlProfilerBindingLoopsRenderPass *instance();
    State *update(const Timeline::TimelineAbstractRenderer *renderer,
                  const Timeline::TimelineRenderState *parentState,
                  State *oldState, int indexFrom, int indexTo, bool stateChanged,
                  qreal spacing) const;
protected:
    QmlProfilerBindingLoopsRenderPass();
};

}
}

#endif // QMLPROFILERBINDINGLOOPSRENDERPASS_H

==> qt-creator-opensource-src-4.3.1.zip: qt-creator-opensource-src-4.3.1/src/plugins/qmlprofiler/qmlprofilerbindingloopsrenderpass.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "qmlprofilerrangemodel.h"

#include "timeline/timelineabstractrenderer.h"
#include "timeline/timelinerenderpass.h"
#include "timeline/timelinerenderstate.h"

#include <QSGMaterial>

namespace QmlProfiler {
namespace Internal {

class QmlProfilerBindingLoopsRenderPass : public Timeline::TimelineRenderPass
{
public:
    static const QmlProfilerBindingLoopsRenderPass *instance();
    State *update(const Timeline::TimelineAbstractRenderer *renderer,
                  const Timeline::TimelineRenderState *parentState,
                  State *oldState, int indexFrom, int indexTo, bool stateChanged,
                  qreal spacing) const;
protected:
    QmlProfilerBindingLoopsRenderPass();
};

} // namespace Internal
} // namespace QmlProfiler
